@@ -109,7 +109,8 @@ def main():
 
     # now do normal startup
     parser = argparse.ArgumentParser(
-        description='Bandit - a Python source code analyzer.'
+        description='Bandit - a Python source code analyzer.',
+        formatter_class=argparse.RawDescriptionHelpFormatter
     )
     parser.add_argument(
         'targets', metavar='targets', type=str, nargs='+',
@@ -170,12 +171,23 @@ def main():
         '-d', '--debug', dest='debug', action='store_true',
         help='turn on debug mode'
     )
+    parser.add_argument(
+        '--ignore-nosec', dest='ignore_nosec', action='store_true',
+        help='do not skip lines with # nosec comments'
+    )
+    parser.add_argument(
+        '-x', '--exclude', dest='excluded_paths', action='store',
+        default='', help='Comma separated list of paths to exclude from scan. '
+                         'Note that these are in addition to the excluded '
+                         'paths provided in the config file.'
+    )
     parser.set_defaults(debug=False)
     parser.set_defaults(verbose=False)
+    parser.set_defaults(ignore_nosec=False)
 
+    plugin_list = '\n\t'.join(sorted(extension_mgr.plugin_names))
     parser.epilog = ('The following plugin suites were discovered and'
-                     ' loaded: [' +
-                     ', '.join(extension_mgr.plugin_names) + ']')
+                     ' loaded:\n\t{0}\n'.format(plugin_list))
 
     # setup work - parse arguments, and initialize BanditManager
     args = parser.parse_args()
@@ -200,7 +212,8 @@ def main():
 
     b_mgr = b_manager.BanditManager(b_conf, args.agg_type, args.debug,
                                     profile_name=args.profile,
-                                    verbose=args.verbose)
+                                    verbose=args.verbose,
+                                    ignore_nosec=args.ignore_nosec)
 
     if args.output_format != "json":
         logger.info("using config: %s", config_file)
@@ -224,12 +237,12 @@ def main():
         sys.exit(2)
 
     # initiate file discovery step within Bandit Manager
-    b_mgr.discover_files(args.targets, args.recursive)
+    b_mgr.discover_files(args.targets, args.recursive, args.excluded_paths)
 
     # initiate execution of tests within Bandit Manager
     b_mgr.run_tests()
-    if args.debug:
-        print(b_mgr.b_ma)
+    logger.debug(b_mgr.b_ma)
+    logger.debug(b_mgr.metrics)
 
     # trigger output of results by Bandit Manager
     sev_level = constants.RANKING[args.severity - 1]
