@@ -14,6 +14,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from collections import Counter
 import fnmatch
 import logging
 import os
@@ -34,7 +35,7 @@ class BanditManager():
     scope = []
 
     def __init__(self, config, agg_type, debug=False, verbose=False,
-                 profile_name=None):
+                 profile_name=None, ignore_nosec=False):
         '''Get logger, config, AST handler, and result store ready
 
         :param config: config options object
@@ -43,16 +44,19 @@ class BanditManager():
         :param debug: Whether to show debug messsages or not
         :param verbose: Whether to show verbose output
         :param profile_name: Optional name of profile to use (from cmd line)
+        :param ignore_nosec: Whether to ignore #nosec or not
         :return:
         '''
         self.debug = debug
         self.verbose = verbose
+        self.ignore_nosec = ignore_nosec
         self.b_conf = config
         self.files_list = []
         self.excluded_files = []
         self.b_ma = b_meta_ast.BanditMetaAst()
         self.skipped = []
         self.results = []
+        self.metrics = {}
         self.agg_type = agg_type
 
         # if the profile name was specified, try to find it in the config
@@ -127,7 +131,7 @@ class BanditManager():
         except IOError:
             print("Unable to write to file: %s" % output_filename)
 
-    def discover_files(self, targets, recursive=False):
+    def discover_files(self, targets, recursive=False, excluded_paths=''):
         '''Add tests directly and from a directory to the test set
 
         :param targets: The command line list of files and directories
@@ -142,6 +146,11 @@ class BanditManager():
         excluded_path_strings = self.b_conf.get_option('exclude_dirs') or []
         included_globs = self.b_conf.get_option('include') or ['*.py']
 
+        # if there are command line provided exclusions add them to the list
+        if excluded_paths:
+            for path in excluded_paths.split(','):
+                excluded_path_strings.append(path)
+
         # build list of files we will analyze
         for fname in targets:
             # if this is a directory and recursive is set, find all files
@@ -212,9 +221,11 @@ class BanditManager():
                 with open(fname, 'rU') as fdata:
                     try:
                         # parse the current file
-                        score = self._execute_ast_visitor(
+                        score, metric = self._execute_ast_visitor(
                             fname, fdata, self.b_ma, self.b_ts)
                         self.scores.append(score)
+                        metric.update(_get_issue_counts([score, ]))
+                        self.metrics[fname] = metric
                     except KeyboardInterrupt as e:
                         sys.exit(2)
             except IOError as e:
@@ -232,6 +243,12 @@ class BanditManager():
         # reflect any files which may have been skipped
         self.files_list = new_files_list
 
+        # do final aggregation of metrics
+        c = Counter()
+        for fname in self.metrics:
+            c.update(self.metrics[fname])
+        self.metrics['_totals'] = dict(c)
+
     def _execute_ast_visitor(self, fname, fdata, b_ma, b_ts):
         '''Execute AST parse on each file
 
@@ -244,11 +261,11 @@ class BanditManager():
         score = []
         if fdata is not None:
             res = b_node_visitor.BanditNodeVisitor(
-                fname, self.b_conf, b_ma, b_ts, self.debug
+                fname, self.b_conf, b_ma, b_ts, self.debug, self.ignore_nosec
             )
-            score = res.process(fdata)
+            score, metrics = res.process(fdata)
             self.results.extend(res.tester.results)
-        return score
+        return score, metrics
 
 
 def _get_files_from_dir(files_dir, included_globs=['*.py'],
@@ -300,3 +317,24 @@ def _matches_glob_list(filename, glob_list):
         if fnmatch.fnmatch(filename, glob):
             return True
     return False
+
+
+def _get_issue_counts(scores):
+    '''Get issue counts aggregated by confidence/severity rankings.
+
+    :param scores: list of scores to aggregate / count
+    :return: aggregated total (count) of issues identified
+    '''
+    issue_counts = {}
+    for score in scores:
+        for (criteria, default) in b_constants.CRITERIA:
+            for i, rank in enumerate(b_constants.RANKING):
+                label = '{0}.{1}'.format(criteria, rank)
+                if label not in issue_counts:
+                    issue_counts[label] = 0
+                    count = (
+                        score[criteria][i] /
+                        b_constants.RANKING_VALUES[rank]
+                    )
+                    issue_counts[label] += count
+    return issue_counts
