@@ -34,13 +34,15 @@ class BanditNodeVisitor(object):
                         'function': None, 'lineno': None, 'skip_lines': None}
 
     def __init__(self, fname, config, metaast, testset,
-                 debug):
+                 debug, ignore_nosec):
         self.debug = debug
+        self.ignore_nosec = ignore_nosec
         self.seen = 0
         self.scores = {
             'SEVERITY': [0] * len(constants.RANKING),
             'CONFIDENCE': [0] * len(constants.RANKING)
         }
+        self.metrics = {'loc': 0, 'nosec': 0}
         self.depth = 0
         self.fname = fname
         self.config = config
@@ -266,10 +268,13 @@ class BanditNodeVisitor(object):
 
         if hasattr(node, 'lineno'):
             self.context['lineno'] = node.lineno
-            if ("# nosec" in self.lines[node.lineno - 1] or
-                    "#nosec" in self.lines[node.lineno - 1]):
-                logger.debug("skipped, nosec")
-                return
+
+            if not self.ignore_nosec:
+                if ("# nosec" in self.lines[node.lineno - 1] or
+                        "#nosec" in self.lines[node.lineno - 1]):
+                    logger.debug("skipped, nosec")
+                    self.metrics['nosec'] += 1
+                    return
 
         self.context['node'] = node
         self.context['linerange'] = b_utils.linerange_fix(node)
@@ -279,6 +284,7 @@ class BanditNodeVisitor(object):
         logger.debug("entering: %s %s [%s]", hex(id(node)), type(node),
                      self.depth)
         self.depth += 1
+        logger.debug(self.context)
 
         method = 'visit_' + node.__class__.__name__
         visitor = getattr(self, method, self.generic_visit)
@@ -329,6 +335,10 @@ class BanditNodeVisitor(object):
         '''
         fdata.seek(0)
         self.lines = fdata.readlines()
+        # only include non-blank lines in the loc metric
+        self.metrics['loc'] += len(
+            [line for line in self.lines if line.strip()]
+        )
         f_ast = ast.parse("".join(self.lines))
         self.generic_visit(f_ast)
-        return self.scores
+        return self.scores, self.metrics
