@@ -49,7 +49,7 @@ class FunctionalTests(testtools.TestCase):
         self.b_mgr.b_conf._settings['plugins_dir'] = path
         self.b_mgr.b_ts = b_test_set.BanditTestSet(config=b_conf)
 
-    def run_example(self, example_script):
+    def run_example(self, example_script, ignore_nosec=False):
         '''A helper method to run the specified test
 
         This method runs the test, which populates the self.b_mgr.scores
@@ -58,10 +58,11 @@ class FunctionalTests(testtools.TestCase):
         :param example_script: Filename of an example script to test
         '''
         path = os.path.join(os.getcwd(), 'examples', example_script)
+        self.b_mgr.ignore_nosec = ignore_nosec
         self.b_mgr.discover_files([path], True)
         self.b_mgr.run_tests()
 
-    def check_example(self, example_script, expect):
+    def check_example(self, example_script, expect, ignore_nosec=False):
         '''A helper method to test the scores for example scripts.
 
         :param example_script: Filename of an example script to test
@@ -69,7 +70,7 @@ class FunctionalTests(testtools.TestCase):
         '''
         # reset scores for subsequent calls to check_example
         self.b_mgr.scores = []
-        self.run_example(example_script)
+        self.run_example(example_script, ignore_nosec=ignore_nosec)
         expected = 0
         result = 0
         for test_scores in self.b_mgr.scores:
@@ -82,6 +83,31 @@ class FunctionalTests(testtools.TestCase):
                 result += sum(test_scores[score_type])
         self.assertEqual(expected, result)
 
+    def check_metrics(self, example_script, expect):
+        '''A helper method to test the metrics being returned.
+
+        :param example_script: Filename of an example script to test
+        :param expect: dict with expected values of metrics
+        '''
+        # reset scores and metrics for subsequent calls to run_example
+        self.b_mgr.scores = []
+        self.b_mgr.metrics = {}
+        self.run_example(example_script)
+        metrics = self.b_mgr.metrics
+        # test general metrics (excludes issue counts)
+        for k in expect:
+            if k != 'issues':
+                self.assertEqual(expect[k], metrics['_totals'][k])
+        # test issue counts
+        if 'issues' in expect:
+            for (criteria, default) in C.CRITERIA:
+                for rank in C.RANKING:
+                    label = '{0}.{1}'.format(criteria, rank)
+                    expected = 0
+                    if expect['issues'].get(criteria, None).get(rank, None):
+                        expected = expect['issues'][criteria][rank]
+                    self.assertEqual(expected, metrics['_totals'][label])
+
     def test_binding(self):
         '''Test the bind-to-0.0.0.0 example.'''
         expect = {'SEVERITY': {'MEDIUM': 1}, 'CONFIDENCE': {'MEDIUM': 1}}
@@ -247,6 +273,11 @@ class FunctionalTests(testtools.TestCase):
         expect = {'SEVERITY': {'LOW': 5}, 'CONFIDENCE': {'HIGH': 5}}
         self.check_example('skip.py', expect)
 
+    def test_ignore_skip(self):
+        ''' Test --ignore-nosec flag.'''
+        expect = {'SEVERITY': {'LOW': 7}, 'CONFIDENCE': {'HIGH': 7}}
+        self.check_example('skip.py', expect, ignore_nosec=True)
+
     def test_sql_statements(self):
         '''Test for SQL injection through string building.'''
         expect = {
@@ -388,6 +419,18 @@ class FunctionalTests(testtools.TestCase):
 
         self.check_example('try_except_pass.py', expect)
 
+    def test_metric_gathering(self):
+        expect = {
+            'nosec': 2, 'loc': 7,
+            'issues': { 'CONFIDENCE': {'HIGH': 5}, 'SEVERITY': {'LOW': 5} }
+        }
+        self.check_metrics('skip.py', expect)
+        expect = {
+            'nosec': 0, 'loc': 4,
+            'issues': { 'CONFIDENCE': {'HIGH': 2}, 'SEVERITY': {'LOW': 2} }
+        }
+        self.check_metrics('imports.py', expect)
+
     def test_weak_cryptographic_key(self):
         '''Test for weak key sizes.'''
         expect = {
